@@ -1,6 +1,3 @@
-import json
-from urllib import urlencode
-
 from social.backends.oauth import BaseOAuth2
 
 
@@ -8,6 +5,7 @@ class InstagramOAuth2(BaseOAuth2):
     name = 'instagram'
     AUTHORIZATION_URL = 'https://instagram.com/oauth/authorize'
     ACCESS_TOKEN_URL = 'https://instagram.com/oauth/access_token'
+    ACCESS_TOKEN_METHOD = 'POST'
 
     def get_user_id(self, details, response):
         return response['user']['id']
@@ -23,10 +21,5 @@ class InstagramOAuth2(BaseOAuth2):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        url = 'https://api.instagram.com/v1/users/self?' + urlencode({
-            'access_token': access_token
-        })
-        try:
-            return json.load(self.urlopen(url))
-        except ValueError:
-            return None
+        return self.get_json('https://api.instagram.com/v1/users/self',
+                             params={'access_token': access_token})
